@@ -2,8 +2,9 @@
  *
  * CGIUTILS.C - Common utilities for Nagios CGIs
  * 
- * Copyright (c) 1999-2008 Ethan Galstad (egalstad@nagios.org)
- * Last Modified: 11-02-2008
+ * Copyright (c) 2009 Nagios Core Development Team and Community Contributors
+ * Copyright (c) 1999-2009 Ethan Galstad (egalstad@nagios.org)
+ * Last Modified: 07-31-2009
  *
  * License:
  *
@@ -113,6 +114,10 @@ int             use_ssl_authentication=FALSE;
 int             default_statusmap_layout_method=0;
 int             default_statuswrl_layout_method=0;
 
+int		color_transparency_index_r=255;
+int		color_transparency_index_g=255;
+int		color_transparency_index_b=255;
+
 extern hostgroup       *hostgroup_list;
 extern contactgroup    *contactgroup_list;
 extern command         *command_list;
@@ -191,6 +196,9 @@ void reset_cgi_vars(void){
 	normal_sound=NULL;
 
 	statusmap_background_image=NULL;
+	color_transparency_index_r=255;
+	color_transparency_index_g=255;
+	color_transparency_index_b=255;
 	statuswrl_include=NULL;
 
 	ping_syntax=NULL;
@@ -375,6 +383,15 @@ int read_cgi_config_file(char *filename){
 		else if(!strcmp(var,"statusmap_background_image"))
 			statusmap_background_image=strdup(val);
 
+		else if(!strcmp(var,"color_transparency_index_r"))
+			color_transparency_index_r=atoi(val);
+                
+		else if(!strcmp(var,"color_transparency_index_g"))
+			color_transparency_index_g=atoi(val);
+
+		else if(!strcmp(var,"color_transparency_index_b"))
+			color_transparency_index_b=atoi(val);
+
 		else if(!strcmp(var,"default_statusmap_layout"))
 			default_statusmap_layout_method=atoi(val);
 
@@ -788,7 +805,7 @@ char *unescape_newlines(char *rawbuf){
 				}
 
 			/* unescape backslashes and other stuff */
-			else{
+			if(rawbuf[x+1]!='\x0'){
 				rawbuf[y++]=rawbuf[x+1];
 				x++;
 				}
@@ -1243,6 +1260,7 @@ char *mmap_fgets(mmapfile *temp_mmapfile){
 char *mmap_fgets_multiline(mmapfile *temp_mmapfile){
 	char *buf=NULL;
 	char *tempbuf=NULL;
+	char *stripped=NULL;
 	int len=0;
 	int len2=0;
 	int end=0;
@@ -1265,11 +1283,15 @@ char *mmap_fgets_multiline(mmapfile *temp_mmapfile){
 			buf[len]='\x0';
 		        }
 		else{
-			len=strlen(tempbuf);
+			/* strip leading white space from continuation lines */
+			stripped=tempbuf;
+			while(*stripped==' ' || *stripped=='\t')
+				stripped++;
+			len=strlen(stripped);
 			len2=strlen(buf);
 			if((buf=(char *)realloc(buf,len+len2+1))==NULL)
 				break;
-			strcat(buf,tempbuf);
+			strcat(buf,stripped);
 			len+=len2;
 			buf[len]='\x0';
 		        }
@@ -1729,7 +1751,7 @@ void display_info_table(char *title,int refresh, authdata *current_authdata){
 	if(refresh==TRUE)
 		printf("Updated every %d seconds<br>\n",refresh_rate);
 
-	printf("Nagios&reg; %s - <A HREF='http://www.nagios.org' TARGET='_new' CLASS='homepageURL'>www.nagios.org</A><BR>\n",PROGRAM_VERSION);
+	printf("Nagios&reg; Core&trade; %s - <A HREF='http://www.nagios.org' TARGET='_new' CLASS='homepageURL'>www.nagios.org</A><BR>\n",PROGRAM_VERSION);
 
 	if(current_authdata!=NULL)
 		printf("Logged in as <i>%s</i><BR>\n",(!strcmp(current_authdata->username,""))?"?":current_authdata->username);
