@@ -2,7 +2,7 @@
  *
  * NOTIFICATIONS.C - Nagios Notifications CGI
  *
- * Copyright (c) 1999-2008 Ethan Galstad (nagios@nagios.org)
+ * Copyright (c) 1999-2008 Ethan Galstad (egalstad@nagios.org)
  * Last Modified: 01-08-2008
  *
  * This CGI program will display the notification events for 
@@ -212,11 +212,11 @@ int main(void){
 		printf("<table border=0 CLASS='optBox'>\n");
 		printf("<form method='GET' action='%s'>\n",NOTIFICATIONS_CGI);
 		if(query_type==FIND_SERVICE){
-			printf("<input type='hidden' name='host' value='%s'>\n",url_encode(query_host_name));
-			printf("<input type='hidden' name='service' value='%s'>\n",url_encode(query_svc_description));
+			printf("<input type='hidden' name='host' value='%s'>\n",escape_string(query_host_name));
+			printf("<input type='hidden' name='service' value='%s'>\n",escape_string(query_svc_description));
 	                }
 		else
-			printf("<input type='hidden' name='%s' value='%s'>\n",(query_type==FIND_HOST)?"host":"contact",url_encode((query_type==FIND_HOST)?query_host_name:query_contact_name));
+			printf("<input type='hidden' name='%s' value='%s'>\n",(query_type==FIND_HOST)?"host":"contact",(query_type==FIND_HOST)?escape_string(query_host_name):escape_string(query_contact_name));
 		printf("<input type='hidden' name='archive' value='%d'>\n",log_archive);
 		printf("<tr>\n");
 		if(query_type==FIND_SERVICE)
@@ -451,6 +451,22 @@ int process_cgivars(void){
 			display_header=FALSE;
                 }
 
+	/* 
+	 * Set some default values if not already set.
+	 * Done here as they won't be set if variable
+	 * not provided via cgi parameters 
+	 * Only required for hosts & contacts, not services 
+	 * as there is no service_name=all option
+	 */
+	if(query_type == FIND_HOST && strlen(query_host_name) == 0) {
+		query_host_name="all";
+		find_all=TRUE;
+		}
+	if(query_type == FIND_CONTACT && strlen(query_contact_name) == 0) {
+		query_contact_name="all";
+		find_all=TRUE;
+		}
+
 	/* free memory allocated to the CGI variables */
 	free_cgivars(variables);
 
